# [mdoc](./mdoc/mdoc.md)

OHHH FUCK! I hate writing docs!
I WANT BURN UP THE DOCS!!
so... I made it.

when I write shortcode : FUCUUUUUUUCKKKCKIJNG!!!! (the code looks sucks, and I think that It need docs even It can't)
when I write my personal libs : GOOOOO THEEEE HELELLELLLLLLLLLL (I write same menual at markdown and python docstring)

## SO I WAS MAD SO I DECIDE TO MAKE IT.
